unit fitsmain1;
// FITS Bilddarstellung Demoprogramm
// O. Nickel, Mainz 2005

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, ComCtrls, ExtCtrls, Menus,
  Imgwin,Gmlib,Abitmap,astro1,inifiles, Buttons{,Math};

const
  Inifilename='fitsdemo1.ini';

type

  TMainform = class(TForm)
    MainMenu1: TMainMenu;
    File1: TMenuItem;
    Exit1: TMenuItem;
    Load1: TMenuItem;
    Panel1: TPanel;
    StatusBar1: TStatusBar;
    OpenDialog1: TOpenDialog;
    Upperscrollbar: TScrollBar;
    LowerScrollBar: TScrollBar;
    LblLower: TLabel;
    LblUpper: TLabel;
    Flipcheck: TCheckBox;
    Label1: TLabel;
    Label2: TLabel;
    Label3: TLabel;
    SaveDialog1: TSaveDialog;
    Loadbutton: TSpeedButton;
    Label5: TLabel;
    Fitsheaderanzeigen1: TMenuItem;
    InfoButton: TSpeedButton;
    procedure Exit1Click(Sender: TObject);
    procedure Getlevels(var image:Timgbuffer; var l1,l2:integer);
    procedure Load1Click(Sender: TObject);
    procedure LowerScrollBarChange(Sender: TObject);
    procedure UpperscrollbarChange(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure Display(filename:string);
    procedure FormCloseQuery(Sender: TObject; var CanClose: Boolean);
    procedure Tile1Click(Sender: TObject);
    procedure LoadbuttonClick(Sender: TObject);
    procedure FlipcheckClick(Sender: TObject);
    procedure Fitsheaderanzeigen1Click(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

  TConfigOptions = class(TObject)
    IniFile         : Tinifile;
    StartupDir      : string;
  public
    constructor create;
    function ReadOptions:boolean;
    function WriteOptions:boolean;
    procedure SetDefaultOptions;
  private
  end;

var
  ConfigOptions: TConfigOptions;
  Progdir: string;
  Mainform: TMainform;
  ImgWin1: Timgform1;
  ImgWin2: Timgform1;
  ImgTrack: Timgform1;
  img: Timgbuffer;
  lowerlevel,upperlevel: single;
  imageLoaded: boolean;
  imagepath: string;

implementation

uses fitsinfo;



{$R *.DFM}
  procedure TConfigOptions.SetDefaultOptions;
  begin
    StartupDir:='';
  end;

  constructor TConfigOptions.Create;
  begin
    inherited create;
    SetDefaultOptions;
  end;

  function TConfigOptions.ReadOptions:boolean;
  begin
    If (Inifile=nil) then Inifile:=Tinifile.create(inifilename);
    StartupDir:=Inifile.ReadString('File','StartupDir',StartupDir);
    ReadOptions:=true;
  end;

  function TConfigOptions.WriteOptions:boolean;
  begin
    WriteOptions:=false;
    If (Inifile=nil) then Inifile:=Tinifile.create(Inifilename);
    Inifile.WriteString('File','StartupDir',StartupDir);
    WriteOptions:=true;
  end;

procedure TMainform.Exit1Click(Sender: TObject);
begin
  Close;
end;


procedure Tmainform.Getlevels(var image:Timgbuffer; var l1,l2:integer);
begin
    LowerLevel:= sqr(Lowerscrollbar.position/100);
    UpperLevel:= sqr(Upperscrollbar.position/100);
    l1:= {image.buffermin+}round(Lowerlevel*(image.buffermax{-image.buffermin}));
    l2:= {image.buffermin+}round(Upperlevel*(image.buffermax{-image.buffermin}));
    LblLower.caption:=INttoStr(l1);
    Lblupper.caption:=Inttostr(l2);
end;

procedure TMainform.Load1Click(Sender: TObject);
var
  l1,l2: integer;
  ext: string;
begin
  if img=nil then
  begin
    img.free;
    img:=Timgbuffer.create;
  end;
  if opendialog1.execute then
  begin
    ext:=ExtractFileExt(opendialog1.FileName);
    if (ext='.bmp') or (ext='.BMP') then
    begin
      if (not img.ReadBMPfile(opendialog1.FileName)) then
      begin
        ShowMessage('Kann BMP Datei nicht laden');
        exit;
      end;
      FitsinfoForm.ClearFitsHeader;
    end else
    begin
      if (not img.readfitsfile(opendialog1.filename)) then
      begin
        ShowMessage('Kann FITS Datei nicht laden');
        exit;
      end;
      FitsinfoForm.ClearFitsheader;
      FitsinfoForm.LoadFitsheader(img.fitsheader);
    end;
    ImagePath:=justPathname(opendialog1.filename);
    opendialog1.initialdir:=ImagePath;
    if Flipcheck.checked then img.flipvertical;
    Imgwin1.free;
    Imgwin1:=TImgform1.create(application);
    Imgwin1.paintbox1.width:=img.xsize;
    Imgwin1.paintbox1.height:=img.ysize;
    Getlevels(img,l1,l2);
    Imgwin1.ShowImage(img, l1,l2);
    ImageLoaded:=true;
 end;
end;

procedure TMainform.LowerScrollBarChange(Sender: TObject);
var
  l1,l2:integer;
begin
  Getlevels(img,l1,l2);
  Imgwin1.ShowImage(img, l1,l2);
end;

procedure TMainform.UpperscrollbarChange(Sender: TObject);
var
  l1,l2:integer;
begin
  Getlevels(img,l1,l2);
  Imgwin1.ShowImage(img, l1,l2);
end;

procedure TMainform.FormCreate(Sender: TObject);
begin
  Progdir:=addbackslash(Extractfiledir(Application.exename));
  ConfigOptions:=TconfigOptions.create;
  ConfigOptions.ReadOptions;
  OpenDIalog1.InitialDir:=ConfigOptions.StartupDir;
  ImageLoaded:=false;
  Imagepath:='';
  img:=Timgbuffer.create;
end;

procedure TMainform.Display(filename:string);
var
  i,l1,l2: integer;

begin
    if ExtractFileExt(filename)='.bmp' then
    begin
      if (not img.ReadBMPfile(filename)) then
      begin
        ShowMessage('Kann BMP Datei nicht laden');
        exit;
      end;
    end else if (not img.readfitsfile(filename)) then
    begin
      ShowMessage('Kann FITS Datei nicht laden');
      exit;
    end;
    if Flipcheck.checked then img.flipvertical;

    Imgwin1.paintbox1.width:=img.xsize;
    Imgwin1.paintbox1.height:=img.ysize;
    Getlevels(img,l1,l2);
    Imgwin1.ShowImage(img, l1,l2);
end;

procedure TMainform.FormCloseQuery(Sender: TObject; var CanClose: Boolean);
begin
  CanClose:=true;
end;

procedure TMainform.Tile1Click(Sender: TObject);
begin
  tile;
end;

procedure TMainform.LoadbuttonClick(Sender: TObject);
begin
   if opendialog1.execute then
   begin
     ConfigOptions.Startupdir:=ExtractFiledir(Opendialog1.FileName);
     ConfigOptions.WriteOptions;
     if img=nil then
     begin
       img.free;
       img:=Timgbuffer.create;
     end;
     ImagePath:=justPathname(opendialog1.filename);
     opendialog1.initialdir:=ImagePath;
     Imgwin1.free;
     Imgwin1:=TImgform1.create(application);
     Display(opendialog1.filename);
     ImageLoaded:=true;
  end else exit;

end;

procedure TMainform.FlipcheckClick(Sender: TObject);
var
  l1,l2:integer;
begin
  If ImageLoaded then
  begin
    img.flipvertical;
    Getlevels(img,l1,l2);
    Imgwin1.ShowImage(img, l1,l2);
  end;
end;

procedure TMainform.Fitsheaderanzeigen1Click(Sender: TObject);
begin
  FitsInfoForm.WindowState:=wsnormal;
  FitsInfoForm.show;
end;

end.
